package com.lantu.sys.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.lantu.common.vo.Result;
import com.lantu.sys.entity.Equip;
import com.lantu.sys.service.IEquipService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author cyf
 * @since 2023-11-15
 */
@RestController
@RequestMapping("/equip")
public class EquipController {
    @Autowired
    private IEquipService equipService;

    @PostMapping
    public Result<?> addEquip(@RequestBody Equip equip){
        equipService.addEquip(equip);
        return Result.success("新增设备成功");
    }

    @PutMapping
    public Result<?> updateEquip(@RequestBody Equip equip){
        equipService.updateById(equip);
        return Result.success("修改设备成功");
    }

    @GetMapping("/{id}")
    public Result<Equip> getEquipById(@PathVariable("id") Integer id){
        Equip equip= equipService.getById(id);
        return Result.success(equip);
    }

    @DeleteMapping("/{id}")
    public Result<Equip> deleteEquipById(@PathVariable("id") Integer id){
        equipService.removeById(id);
        return Result.success("删除设备成功");
    }


    @GetMapping("/list")
    public Result<Map<String,Object>> getEquipList(@RequestParam(value = "status",required = false) String status,
                                                  @RequestParam(value = "facol",required = false) String facol,
                                                  @RequestParam(value = "pageNo") Long pageNo,
                                                  @RequestParam(value = "pageSize") Long pageSize){
        LambdaQueryWrapper<Equip> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(StringUtils.hasLength(status),Equip::getx2,status);
        wrapper.eq(StringUtils.hasLength(facol),Equip::getFocal,facol);
        wrapper.orderByDesc(Equip::getId);
        Page<Equip> page = new Page<>(pageNo,pageSize);
        equipService.page(page,wrapper);
        Map<String,Object> data = new HashMap<>();
        data.put("total",page.getTotal());
        data.put("rows",page.getRecords());
        return Result.success(data);


    }




}
